﻿
using System;
using System.Collections.Generic;
using System.IO;
using Wisej.Core;
using Wisej.Web;

namespace Wisej.DXMasterDetailViewSample
{
	public partial class Page1 : Page
	{
		// an internal list of employee tasks.
		private List<DynamicObject> tasks;

		public Page1()
		{
			InitializeComponent();
		}

		private void Page1_Load(object sender, EventArgs e)
		{
			// the postback url of the widget.
			var serviceUrl = this.dxDataGrid1.GetPostbackURL();

			this.dxDataGrid1.Options = new
			{
				// redirect data requests to the WebRequest handler.
				dataSource = serviceUrl + "&action=getEmployees",
				showBorders = true,
				columns = new dynamic[]
				{
					new
					{
						dataField = "Prefix",
						caption = "Title",
						width = 70
					},
					new
					{
						dataField = "FirstName",
					},
					new
					{
						dataField = "LastName",
					},
					new
					{
						dataField = "Position",
						width = 170
					},
					new
					{
						dataField = "State",
						width = 125
					},
					new
					{
						dataField = "BirthDate",
						dataType = "date"
					}
				},
				masterDetail = new
				{
					enabled = true,
					// the name of the template in WidgetFunctions.
					template = "detailTemplateInit"
				}
			};
		}

		/// <summary>
		/// Reads and parses the employees data file.
		/// </summary>
		/// <returns>A dynamic array of employees from the employees data file.</returns>
		public object GetEmployees()
		{
			var employeesText = File.ReadAllText(Application.MapPath("Data/employees.json"));

			return JSON.Parse(employeesText).employees;
		}

		/// <summary>
		/// parses the tasks data file and searches for the tasks of the given employee.
		/// </summary>
		/// <returns>A dynamic list of tasks.</returns>
		public object GetTasksForEmployee(int id)
		{
			// initially populate the tasks.
			if (this.tasks == null)
            {
				var tasksText = File.ReadAllText(Application.MapPath("Data/tasks.json"));
				this.tasks = new List<DynamicObject>(JSON.Parse(tasksText).tasks);
			}

			// search for and return the tasks for the specified employee.
			return this.tasks.FindAll((e) => int.Parse(e["EmployeeID"].ToString()) == id);
		}

        private void dxDataGrid1_WidgetEvent(object sender, WidgetEventArgs e)
        {
            switch (e.Type)
            {
                // capture parent cell click.
                case "cellClick":
                    break;

				// capture child cell click.
				case "childCellClick":
					AlertBox.Show(
						$"<b>{e.Type}</b><br/>{JSON.Stringify(e.Data)}",
						MessageBoxIcon.Information);

					Application.Play(MessageBoxIcon.Information);
					break;

			}
		}

        private void dxDataGrid1_WebRequest(object sender, WebRequestEventArgs e)
        {
			switch (e.Request.Params["action"])
            {
				// the client widget is asking for the employees json list.
				case "getEmployees":
					e.Response.Write(GetEmployees().ToJSON(false));
					break;

				// the client is asking for the tasks for a specific employee.
				case "getTasks":
					var id = int.Parse(e.Request.Params["employeeID"]);

					e.Response.Write(GetTasksForEmployee(id).ToJSON(false));
					break;
            }
        }
    }
}
